import "Turbine";
import "Turbine.UI";
import "Turbine.UI.Lotro";

pluginData = Turbine.PluginData.Load(Turbine.DataScope.Character, 'OPL') or {
	plugins = {},
}

-- The highest Ordered Load Number (i.e., the last plugin to load)
greatestLoadNumber = 0

for k, v in pairs( pluginData.plugins ) do
	if( greatestLoadNumber < v ) then
		greatestLoadNumber = v;
	end
end

function LoadPlugins()
	for loop=1, greatestLoadNumber do
		for k, v in pairs(pluginData.plugins) do
			if v == loop then
				Turbine.PluginManager.LoadPlugin(k)
			end
		end
	end
end

-- create a new command line command for OPL options
oplCommand = Turbine.ShellCommand();

-- handle the chat commands
function oplCommand:Execute( name, shellCommand )
	if ( string.find( shellCommand, "add" ) ~= nil ) then
		pluginNameStart = string.find( shellCommand, "\"" );
		if ( pluginNameStart ~= nil ) then
			pluginNameEnd = string.find( shellCommand, "\"", pluginNameStart+1 );
		end
		pluginName = string.sub( shellCommand, pluginNameStart+1, pluginNameEnd-1 );
		pluginLoadNumberStart = string.find( shellCommand, " ", pluginNameEnd );
		pluginLoadNumberEnd = string.find( shellCommand, " ", pluginLoadNumberStart+1 );
		if ( pluginLoadNumberEnd ~= nil ) then
			pluginLoadNumber = string.sub( shellCommand, pluginLoadNumberStart+1, pluginLoadNumberEnd-1 );
		else pluginLoadNumber = string.sub( shellCommand, pluginLoadNumberStart+1 );
		end
		pluginData.plugins[pluginName] = pluginLoadNumber;
		SavePlugin();
		Turbine.Shell.WriteLine( "\"" .. pluginName .. "\" was added to the loading list with a loading order number of " .. pluginLoadNumber .. ".");
	elseif ( string.find( shellCommand, "remove" ) ~= nil ) then
		pluginNameStart = string.find( shellCommand, "\"" );
		if ( pluginNameStart ~= nil ) then
			pluginNameEnd = string.find( shellCommand, "\"", pluginNameStart+1 );
		end
		pluginName = string.sub( shellCommand, pluginNameStart+1, pluginNameEnd-1 );
		pluginData.plugins[pluginName] = nil;
		SavePlugin();
		Turbine.Shell.WriteLine( "\"" .. pluginName .. "\" was removed from the loading list. It will no longer load when OPL is loaded.");
		-- remove plugin, save
	elseif ( shellCommand == "list" ) then
		for loop=1, greatestLoadNumber do
			for k, v in pairs(pluginData.plugins) do
				if v == loop then
					Turbine.Shell.WriteLine( v .. " - " .. k );
				end
			end
		end
	elseif ( shellCommand ~= nil ) then
		oplCommand:GetHelp();
	end
end

-- Saves the plugin
function SavePlugin()
	Turbine.PluginData.Save( Turbine.DataScope.Character, 'OPL', pluginData );
end


-- Removes a plugin from the loading list
--function RemovePlugin( pluginName )

-- The Help text that outputs when /opl is typed
help = "OPL has the following commands:\n" ..
	"opl add \"[PluginName]\" [Ordered Load Number]: Add a plugin to the loading list at a specific spot.\n     Be sure to include the \"\" around the PluginName, otherwise it will not register the name correctly.\n     [Ordered Load Number] does not have to differ between plugins, but plugins with the same Ordered Load Number will load with the other Plugins of the same number in an unknown order.\n" ..
	"opl remove \"[PluginName]\": Remove a plugin from the loading list. Be sure to include the \"\" around the PluginName, otherwise it will not register the name correctly.\n" ..
	"opl list: Lists the plugins in the order that they are loaded. Note that if multiple plugins have the same number listed next to them, then all those Plugins (with the same number) will load in a RANDOM order (of each other).";

function oplCommand:GetHelp()
	Turbine.Shell.WriteLine( help );
end

-- add the command to the shell
Turbine.Shell.AddCommand( "opl", oplCommand );

LoadPlugins()